@@ -61,8 +61,8 @@ Creates a new local agent for a given url
 
 The url where the agent is deployed. This is a mandatory parameter. The url
 must include the context within the server, which is typically based on the
-name of the war archive. Example: http://localhost:8080/jjagent for a drop in
-deployment of the agent in a standard Tomcat's webapp directory. 
+name of the war archive. Example: C<http://localhost:8080/j4p-agent> for a drop
+in deployment of the agent in a standard Tomcat's webapp directory.
 
 =item timeout => <timeout>
 
@@ -117,7 +117,7 @@ sub init {
 =item $resp = $agent->request($request)
 
 Implementation of the JMX request as specified in L<JMX::Jmx4Perl>. It uses a
-L<HTTP:Request> sent via an L<LWP::UserAgent> for posting a JSON representation
+L<HTTP::Request> sent via an L<LWP::UserAgent> for posting a JSON representation
 of the request. This method shouldn't be called directly but via
 L<JMX::Jmx4Perl>->request(). 
 
@@ -129,30 +129,34 @@ sub request {
  
     my $ua = $self->{ua};
     my $url = $self->request_url($jmx_request);
+#    print $url;
     my $req = HTTP::Request->new(GET => $url);
     my $resp = $ua->request($req);
-    my $ret;
+    my $ret = {};
     eval {
         $ret = from_json($resp->content());
     };
     if ($@) {
-        return new JMX::Jmx4Perl::Response->new
-          ( 
-           $resp->code,
-           $jmx_request,
-           $resp->content,
-           "Error while deserializing JSON answer (probably wrong URL)"
-          );
+        if (!$resp->is_error) {
+            return new JMX::Jmx4Perl::Response->new
+              ( 
+               400,
+               $jmx_request,
+               $resp->content,
+               "Error while deserializing JSON answer (probably wrong URL)"
+              );
+        }
     }
-    croak "Error while deserializing ",$resp->content," : ",$@ if $@;
     if ($resp->is_error && !$ret->{status}) {
-        my $error = "Error while fetching $url :\n" . $resp->status_line . "\n";
+        my $error = "Error while fetching $url :\n\n" . $resp->status_line . "\n";
         my $content = $resp->content;
         if ($content) {
             chomp $content;
-            $error .=  $content if $content ne $resp->status_line;
+            $error .=  "=" x length($resp->status_line) . "\n\n";
+            my $short = substr($content,0,500);
+            $error .=  $short . (length($short) < length($content) ? "\n\n.......\n\n" : "") . "\n" if $content ne $resp->status_line;
         }
-        croak $error;
+        die $error;
     };
     return JMX::Jmx4Perl::Response->new($ret->{status},$jmx_request,$ret->{value},$ret->{error},$ret->{stacktrace});
 }
@@ -171,14 +175,18 @@ sub request_url {
     my $type = $request->get("type");
     $url .= $type . "/";
     $url .= $self->_escape($request->get("mbean")) . "/";
-    if ($type eq READ || $type eq WRITE) {
+    if ($type eq READ) {
         $url .= $self->_escape($request->get("attribute"));
-        $url .= "/" . $self->_escape($request->get("path")) if $request->get("path");
-        if ($type eq WRITE) {
-            $url .= "/" . $self->_escape($request->get("value"));
-        }
+        $url .= "/" . $self->_escape($request->get("path")) if defined($request->get("path"));
+    } elsif ($type eq WRITE) {
+        $url .= $self->_escape($request->get("attribute"));
+        $url .= "/" . $self->_escape($request->get("value"));
+        $url .= "/" . $self->_escape($request->get("path")) if defined($request->get("path"));
     } elsif ($type eq LIST) {
-        $url .= $self->_escape($request->get("path")) if $request->get("path");
+        $url .= $self->_escape($request->get("path")) if defined($request->get("path"));
+    } elsif ($type eq EXEC) {
+        $url .= $self->_escape($request->get("operation"));
+        $url .= "/" . $self->_escape($_) for @{$request->get("args")};
     }
     return $url;
 }
